package com.zd.laboratory.service;

import com.zd.laboratory.domain.LabPhotoNote;
import com.zd.laboratory.domain.dto.LabPhotoNoteADD;
import com.zd.laboratory.domain.vo.LabPhotoNoteListVO;
import com.zd.laboratory.domain.vo.LabPhotoNoteVO;

import java.util.List;

/**
 * 随手拍记录Service接口
 *
 * @author 周攀
 * @date 2021-09-10
 */
public interface ILabPhotoNoteService {
    /**
     * 查询随手拍记录
     *
     * @param id 随手拍记录主键
     * @return 随手拍记录
     */
    public LabPhotoNote selectLabPhotoNoteById(Long id);

    /**
     * 查询随手拍记录列表
     *
     * @param labPhotoNote 随手拍记录
     * @return 随手拍记录集合
     */
    public List<LabPhotoNote> selectLabPhotoNoteList(LabPhotoNote labPhotoNote);


    /**
     * 查询随手拍记录列表-VO
     *
     * @param labPhotoNote 随手拍记录
     * @return 随手拍记录
     */
    public List<LabPhotoNoteListVO> selectLabPhotoNoteVOList(LabPhotoNote labPhotoNote);

    /**
     * 新增随手拍记录
     *
     * @param labPhotoNote 随手拍记录
     * @return 结果
     */
    public int insertLabPhotoNote(LabPhotoNote labPhotoNote);

    /**
     * 保存随手拍记录 并返回ID
     *
     * @param labPhotoNote 随手拍记录
     * @return 结果
     */
    public Long saveLabPhotoNote(LabPhotoNoteADD labPhotoNote);

    /**
     * 修改随手拍记录
     *
     * @param labPhotoNote 随手拍记录
     * @return 结果
     */
    public int updateLabPhotoNote(LabPhotoNote labPhotoNote);

    /**
     * 批量删除随手拍记录
     *
     * @param ids 需要删除的随手拍记录主键集合
     * @return 结果
     */
    public int deleteLabPhotoNoteByIds(Long[] ids);

    /**
     * 删除随手拍记录信息
     *
     * @param id 随手拍记录主键
     * @return 结果
     */
    public int deleteLabPhotoNoteById(Long id);


    /**
     * 查询登录人接收随手拍统计
     *
     * @param labPhotoNote 随手拍记录
     * @return 查询登录人接收随手拍统计
     */
    public LabPhotoNoteVO receivePhotoNote(LabPhotoNote labPhotoNote);
}
